/* Protocols.c -- This file contains these three functions:

                    CreateWindowManagerProtocols() -- which sets up the
                                                      window manager protocols
                                                      to trap the Close command.

                    CreateSessionManagerProtocols() -- which sets up the
                                                       needed protocol with
                                                       a session manager.

                    SaveSessionCB() -- a callback routine that is invoked 
                                       whenever the application receives a
                                       "save yourself" message from the
                                       session manager.  */

#include "Global.h"
#include "Menu.h"

void SaveSessionCB();


/****************************************************************** 
   C r e a t e   W i n d o w   M a n a g e r   P r o t o c o l s
 ****************************************************************** 
   This function establishes a protocol callback that detects 
   the window manager's Close command. 
 ******************************************************************/

void CreateWindowManagerProtocols(shell)
     Widget shell;
{
  Atom  XaWmDeleteWindow;

  XaWmDeleteWindow=XInternAtom(XtDisplay(topLevel),"WM_DELETE_WINDOW", False);
  XmAddWMProtocolCallback (shell, XaWmDeleteWindow, MenuCB, MENU_File_Exit);
}


/****************************************************************** 
  C r e a t e   S e s s i o n   M a n a g e r   P r o t o c o l s
 ****************************************************************** 
   This function establishes a protocol callback to detect a "save 
   yourself" message from an ICCCM-compliant session manager.
 ******************************************************************/

void CreateSessionManagerProtocols(shell)
     Widget  shell;
{
  Atom  XaWmSaveYourself;

  XaWmSaveYourself=XInternAtom(XtDisplay(shell),"WM_SAVE_YOURSELF", False);
  XmAddWMProtocolCallback (shell, XaWmSaveYourself, SaveSessionCB, NULL);
}


/*****************************************************************
              S a v e   S e s s i o n   C a l l b a c k
 *****************************************************************
   This callback function is executed whenever this application 
   receives a "save yourself" message from an ICCCM-compliant
   session manager.
 *****************************************************************/

void SaveSessionCB(w, client_data, call_data)
     Widget  w;
     XtPointer client_data;
     XtPointer call_data;
{

   printf("This is when the application should save\n");
   printf("its current state in a session file!\n");

   /* Ideally, a session file should save enough application-specific
      information to restart the application and return it to the
      current state, as though the user was never interrupted.  */

   /* This routine should also update the top-level window's 
      WM_COMMAND property.  This signals the session manager
      that the application is done saving itself.  (Refer to the 
      man page for XSetCommand().)  */

   /* For more information about session management, refer to the 
      "Inter-Client Conventions Manual" (ICCCM) and to the "HP VUE 
      Programmer's Guide."  */

}

